pub struct PanexConfig {
pub favorites: FavoritesConfig,
pub open: OpenConfig,
}Fields
favorites: FavoritesConfigopen: OpenConfigImplementations
Sourceimpl PanexConfig
impl PanexConfig
Sourcepub fn config_path() -> Result<PathBuf, String>
pub fn config_path() -> Result<PathBuf, String>
Returns ~/.panex/config.toml
pub fn is_favorite(&self, path: &str) -> bool
pub fn add_favorite(&mut self, path: &str) -> Result<(), String>
pub fn remove_favorite(&mut self, path: &str) -> Result<(), String>
pub fn toggle_favorite(&mut self, path: &str) -> Result<bool, String>
Sourcepub fn get_gui_app(&self, ext: &str) -> Option<&String>
pub fn get_gui_app(&self, ext: &str) -> Option<&String>
Get the custom app for a file extension in GUI mode.
Sourcepub fn get_tui_app(&self, ext: &str) -> Option<&String>
pub fn get_tui_app(&self, ext: &str) -> Option<&String>
Get the custom command for a file extension in TUI mode.